@@ -1,4 +1,4 @@
-// Copyright (C) 2002-2010 Nikolaus Gebhardt
+// Copyright (C) 2002-2012 Nikolaus Gebhardt
 // This file is part of the "Irrlicht Engine".
 // For conditions of distribution and use, see copyright notice in irrlicht.h
 
@@ -7,12 +7,12 @@
 
 //! Irrlicht SDK Version
 #define IRRLICHT_VERSION_MAJOR 1
-#define IRRLICHT_VERSION_MINOR 7
+#define IRRLICHT_VERSION_MINOR 8
 #define IRRLICHT_VERSION_REVISION 2
 // This flag will be defined only in SVN, the official release code will have
 // it undefined
-#define IRRLICHT_VERSION_SVN -beta
-#define IRRLICHT_SDK_VERSION "1.7.2"
+//#define IRRLICHT_VERSION_SVN -alpha
+#define IRRLICHT_SDK_VERSION "1.8.2"
 
 #include <stdio.h> // TODO: Although included elsewhere this is required at least for mingw
 
@@ -37,12 +37,24 @@
 //! _IRR_COMPILE_WITH_CONSOLE_DEVICE_ for no windowing system, used as a fallback
 //! _IRR_COMPILE_WITH_FB_DEVICE_ for framebuffer systems
 
+//! Passing defines to the compiler which have NO in front of the _IRR definename is an alternative
+//! way which can be used to disable defines (instead of outcommenting them in this header).
+//! So defines can be controlled from Makefiles or Projectfiles which allows building
+//! different library versions without having to change the sources.
+//! Example: NO_IRR_COMPILE_WITH_X11_ would disable X11
+
 
 //! Uncomment this line to compile with the SDL device
 //#define _IRR_COMPILE_WITH_SDL_DEVICE_
+#ifdef NO_IRR_COMPILE_WITH_SDL_DEVICE_
+#undef _IRR_COMPILE_WITH_SDL_DEVICE_
+#endif
 
 //! Comment this line to compile without the fallback console device.
 #define _IRR_COMPILE_WITH_CONSOLE_DEVICE_
+#ifdef NO_IRR_COMPILE_WITH_CONSOLE_DEVICE_
+#undef _IRR_COMPILE_WITH_CONSOLE_DEVICE_
+#endif
 
 //! WIN32 for Windows32
 //! WIN64 for Windows64
@@ -90,12 +102,16 @@
 #define _IRR_LINUX_PLATFORM_
 #endif
 #define _IRR_POSIX_API_
-#define _IRR_USE_LINUX_DEVICE_
 #define _IRR_COMPILE_WITH_X11_DEVICE_
 #endif
 
+
 //! Define _IRR_COMPILE_WITH_JOYSTICK_SUPPORT_ if you want joystick events.
-//#define _IRR_COMPILE_WITH_JOYSTICK_EVENTS_
+#define _IRR_COMPILE_WITH_JOYSTICK_EVENTS_
+#ifdef NO_IRR_COMPILE_WITH_JOYSTICK_EVENTS_
+#undef _IRR_COMPILE_WITH_JOYSTICK_EVENTS_
+#endif
+
 
 //! Maximum number of texture an SMaterial can have, up to 8 are supported by Irrlicht.
 #define _IRR_MATERIAL_MAX_TEXTURES_ 4
@@ -117,31 +133,62 @@ headers, e.g. Summer 2004.  This is a Microsoft issue, not an Irrlicht one.
 */
 #if defined(_IRR_WINDOWS_API_) && (!defined(__GNUC__) || defined(IRR_COMPILE_WITH_DX9_DEV_PACK))
 
+//! Define _IRR_COMPILE_WITH_DIRECTINPUT_JOYSTICK_ if you want to use DirectInput for joystick handling.
+/** This only applies to Windows devices, currently only supported under Win32 device.
+If not defined, Windows Multimedia library is used, which offers also broad support for joystick devices. */
+#define _IRR_COMPILE_WITH_DIRECTINPUT_JOYSTICK_
+#ifdef NO_IRR_COMPILE_WITH_DIRECTINPUT_JOYSTICK_
+#undef _IRR_COMPILE_WITH_DIRECTINPUT_JOYSTICK_
+#endif
+// can't get this to compile currently under borland, can be removed if someone has a better solution
+#if defined(__BORLANDC__)
+#undef _IRR_COMPILE_WITH_DIRECTINPUT_JOYSTICK_
+#endif
+
 //! Only define _IRR_COMPILE_WITH_DIRECT3D_8_ if you have an appropriate DXSDK, e.g. Summer 2004
-//#define _IRR_COMPILE_WITH_DIRECT3D_8_
+// #define _IRR_COMPILE_WITH_DIRECT3D_8_
 #define _IRR_COMPILE_WITH_DIRECT3D_9_
 
+#ifdef NO_IRR_COMPILE_WITH_DIRECT3D_8_
+#undef _IRR_COMPILE_WITH_DIRECT3D_8_
+#endif
+#ifdef NO_IRR_COMPILE_WITH_DIRECT3D_9_
+#undef _IRR_COMPILE_WITH_DIRECT3D_9_
+#endif
+
 #endif
 
 //! Define _IRR_COMPILE_WITH_OPENGL_ to compile the Irrlicht engine with OpenGL.
 /** If you do not wish the engine to be compiled with OpenGL, comment this
 define out. */
 #define _IRR_COMPILE_WITH_OPENGL_
+#ifdef NO_IRR_COMPILE_WITH_OPENGL_
+#undef _IRR_COMPILE_WITH_OPENGL_
+#endif
 
 //! Define _IRR_COMPILE_WITH_SOFTWARE_ to compile the Irrlicht engine with software driver
 /** If you do not need the software driver, or want to use Burning's Video instead,
 comment this define out */
 #define _IRR_COMPILE_WITH_SOFTWARE_
+#ifdef NO_IRR_COMPILE_WITH_SOFTWARE_
+#undef _IRR_COMPILE_WITH_SOFTWARE_
+#endif
 
 //! Define _IRR_COMPILE_WITH_BURNINGSVIDEO_ to compile the Irrlicht engine with Burning's video driver
 /** If you do not need this software driver, you can comment this define out. */
 #define _IRR_COMPILE_WITH_BURNINGSVIDEO_
+#ifdef NO_IRR_COMPILE_WITH_BURNINGSVIDEO_
+#undef _IRR_COMPILE_WITH_BURNINGSVIDEO_
+#endif
 
 //! Define _IRR_COMPILE_WITH_X11_ to compile the Irrlicht engine with X11 support.
 /** If you do not wish the engine to be compiled with X11, comment this
 define out. */
 // Only used in LinuxDevice.
 #define _IRR_COMPILE_WITH_X11_
+#ifdef NO_IRR_COMPILE_WITH_X11_
+#undef _IRR_COMPILE_WITH_X11_
+#endif
 
 //! Define _IRR_OPENGL_USE_EXTPOINTER_ if the OpenGL renderer should use OpenGL extensions via function pointers.
 /** On some systems there is no support for the dynamic extension of OpenGL
@@ -152,44 +199,76 @@ define out. */
 
 //! On some Linux systems the XF86 vidmode extension or X11 RandR are missing. Use these flags
 //! to remove the dependencies such that Irrlicht will compile on those systems, too.
+//! If you don't need colored cursors you can also disable the Xcursor extension
 #if defined(_IRR_LINUX_PLATFORM_) && defined(_IRR_COMPILE_WITH_X11_)
 #define _IRR_LINUX_X11_VIDMODE_
 //#define _IRR_LINUX_X11_RANDR_
+#ifdef NO_IRR_LINUX_X11_VIDMODE_
+#undef _IRR_LINUX_X11_VIDMODE_
+#endif
+#ifdef NO_IRR_LINUX_X11_RANDR_
+#undef _IRR_LINUX_X11_RANDR_
+#endif
+
+//! X11 has by default only monochrome cursors, but using the Xcursor library we can also get color cursor support.
+//! If you have the need for custom color cursors on X11 then enable this and make sure you also link
+//! to the Xcursor library in your Makefile/Projectfile.
+//#define _IRR_LINUX_XCURSOR_
+#ifdef NO_IRR_LINUX_XCURSOR_
+#undef _IRR_LINUX_XCURSOR_
+#endif
+
 #endif
 
 //! Define _IRR_COMPILE_WITH_GUI_ to compile the engine with the built-in GUI
 /** Disable this if you are using an external library to draw the GUI. If you disable this then
 you will not be able to use anything provided by the GUI Environment, including loading fonts. */
 #define _IRR_COMPILE_WITH_GUI_
-
+#ifdef NO_IRR_COMPILE_WITH_GUI_
+#undef _IRR_COMPILE_WITH_GUI_
+#endif
 
 //! Define _IRR_WCHAR_FILESYSTEM to enable unicode filesystem support for the engine.
 /** This enables the engine to read/write from unicode filesystem. If you
 disable this feature, the engine behave as before (ansi). This is currently only supported
-for Windows based systems. */
+for Windows based systems. You also have to set #define UNICODE for this to compile.
+*/
 //#define _IRR_WCHAR_FILESYSTEM
+#ifdef NO_IRR_WCHAR_FILESYSTEM
+#undef _IRR_WCHAR_FILESYSTEM
+#endif
 
 //! Define _IRR_COMPILE_WITH_JPEGLIB_ to enable compiling the engine using libjpeg.
 /** This enables the engine to read jpeg images. If you comment this out,
 the engine will no longer read .jpeg images. */
 #define _IRR_COMPILE_WITH_LIBJPEG_
+#ifdef NO_IRR_COMPILE_WITH_LIBJPEG_
+#undef _IRR_COMPILE_WITH_LIBJPEG_
+#endif
 
 //! Define _IRR_USE_NON_SYSTEM_JPEG_LIB_ to let irrlicht use the jpeglib which comes with irrlicht.
 /** If this is commented out, Irrlicht will try to compile using the jpeg lib installed in the system.
 	This is only used when _IRR_COMPILE_WITH_LIBJPEG_ is defined. */
-//#define _IRR_USE_NON_SYSTEM_JPEG_LIB_
-
+#define _IRR_USE_NON_SYSTEM_JPEG_LIB_
+#ifdef NO_IRR_USE_NON_SYSTEM_JPEG_LIB_
+#undef _IRR_USE_NON_SYSTEM_JPEG_LIB_
+#endif
 
 //! Define _IRR_COMPILE_WITH_LIBPNG_ to enable compiling the engine using libpng.
 /** This enables the engine to read png images. If you comment this out,
 the engine will no longer read .png images. */
 #define _IRR_COMPILE_WITH_LIBPNG_
+#ifdef NO_IRR_COMPILE_WITH_LIBPNG_
+#undef _IRR_COMPILE_WITH_LIBPNG_
+#endif
 
 //! Define _IRR_USE_NON_SYSTEM_LIBPNG_ to let irrlicht use the libpng which comes with irrlicht.
 /** If this is commented out, Irrlicht will try to compile using the libpng installed in the system.
 	This is only used when _IRR_COMPILE_WITH_LIBPNG_ is defined. */
-//#define _IRR_USE_NON_SYSTEM_LIB_PNG_
-
+#define _IRR_USE_NON_SYSTEM_LIB_PNG_
+#ifdef NO_IRR_USE_NON_SYSTEM_LIB_PNG_
+#undef _IRR_USE_NON_SYSTEM_LIB_PNG_
+#endif
 
 //! Define _IRR_D3D_NO_SHADER_DEBUGGING to disable shader debugging in D3D9
 /** If _IRR_D3D_NO_SHADER_DEBUGGING is undefined in IrrCompileConfig.h,
@@ -202,6 +281,9 @@ the file you want to debug into visual studio. That's it. You can now set breakp
 watch registers, variables etc. This works with ASM, HLSL, and both with pixel and vertex shaders.
 Note that the engine will run in D3D REF for this, which is a lot slower than HAL. */
 #define _IRR_D3D_NO_SHADER_DEBUGGING
+#ifdef NO_IRR_D3D_NO_SHADER_DEBUGGING
+#undef _IRR_D3D_NO_SHADER_DEBUGGING
+#endif
 
 //! Define _IRR_D3D_USE_LEGACY_HLSL_COMPILER to enable the old HLSL compiler in recent DX SDKs
 /** This enables support for ps_1_x shaders for recent DX SDKs. Otherwise, support
@@ -209,6 +291,18 @@ for this shader model is not available anymore in SDKs after Oct2006. You need t
 distribute the OCT2006_d3dx9_31_x86.cab or OCT2006_d3dx9_31_x64.cab though, in order
 to provide the user with the proper DLL. That's why it's disabled by default. */
 //#define _IRR_D3D_USE_LEGACY_HLSL_COMPILER
+#ifdef NO_IRR_D3D_USE_LEGACY_HLSL_COMPILER
+#undef _IRR_D3D_USE_LEGACY_HLSL_COMPILER
+#endif
+
+//! Define _IRR_COMPILE_WITH_CG_ to enable Cg Shading Language support
+//#define _IRR_COMPILE_WITH_CG_
+#ifdef NO_IRR_COMPILE_WITH_CG_
+#undef _IRR_COMPILE_WITH_CG_
+#endif
+#if !defined(_IRR_COMPILE_WITH_OPENGL_) && !defined(_IRR_COMPILE_WITH_DIRECT3D_9_)
+#undef _IRR_COMPILE_WITH_CG_
+#endif
 
 //! Define _IRR_USE_NVIDIA_PERFHUD_ to opt-in to using the nVidia PerHUD tool
 /** Enable, by opting-in, to use the nVidia PerfHUD performance analysis driver
@@ -241,141 +335,332 @@ tool <http://developer.nvidia.com/object/nvperfhud_home.html>. */
 //! Uncomment the following line if you want to ignore the deprecated warnings
 //#define IGNORE_DEPRECATED_WARNING
 
+//! Define _IRR_COMPILE_WITH_IRR_SCENE_LOADER_ if you want to be able to load
+/** .irr scenes using ISceneManager::loadScene */
+#define _IRR_COMPILE_WITH_IRR_SCENE_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_IRR_SCENE_LOADER_
+#undef _IRR_COMPILE_WITH_IRR_SCENE_LOADER_
+#endif
+
 //! Define _IRR_COMPILE_WITH_SKINNED_MESH_SUPPORT_ if you want to use bone based
 /** animated meshes. If you compile without this, you will be unable to load
 B3D, MS3D or X meshes */
 #define _IRR_COMPILE_WITH_SKINNED_MESH_SUPPORT_
+#ifdef NO_IRR_COMPILE_WITH_SKINNED_MESH_SUPPORT_
+#undef _IRR_COMPILE_WITH_SKINNED_MESH_SUPPORT_
+#endif
 
 #ifdef _IRR_COMPILE_WITH_SKINNED_MESH_SUPPORT_
 //! Define _IRR_COMPILE_WITH_B3D_LOADER_ if you want to use Blitz3D files
 #define _IRR_COMPILE_WITH_B3D_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_B3D_LOADER_
+#undef _IRR_COMPILE_WITH_B3D_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_MS3D_LOADER_ if you want to Milkshape files
 #define _IRR_COMPILE_WITH_MS3D_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_MS3D_LOADER_
+#undef _IRR_COMPILE_WITH_MS3D_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_X_LOADER_ if you want to use Microsoft X files
 #define _IRR_COMPILE_WITH_X_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_X_LOADER_
+#undef _IRR_COMPILE_WITH_X_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_OGRE_LOADER_ if you want to load Ogre 3D files
 #define _IRR_COMPILE_WITH_OGRE_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_OGRE_LOADER_
+#undef _IRR_COMPILE_WITH_OGRE_LOADER_
 #endif
+#endif	// _IRR_COMPILE_WITH_SKINNED_MESH_SUPPORT_
 
 //! Define _IRR_COMPILE_WITH_IRR_MESH_LOADER_ if you want to load Irrlicht Engine .irrmesh files
 #define _IRR_COMPILE_WITH_IRR_MESH_LOADER_
-
+#ifdef NO_IRR_COMPILE_WITH_IRR_MESH_LOADER_
+#undef _IRR_COMPILE_WITH_IRR_MESH_LOADER_
+#endif
+//! Define _IRR_COMPILE_WITH_HALFLIFE_LOADER_ if you want to load Halflife animated files
+#define _IRR_COMPILE_WITH_HALFLIFE_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_HALFLIFE_LOADER_
+#undef _IRR_COMPILE_WITH_HALFLIFE_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_MD2_LOADER_ if you want to load Quake 2 animated files
 #define _IRR_COMPILE_WITH_MD2_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_MD2_LOADER_
+#undef _IRR_COMPILE_WITH_MD2_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_MD3_LOADER_ if you want to load Quake 3 animated files
 #define _IRR_COMPILE_WITH_MD3_LOADER_
-
+#ifdef NO_IRR_COMPILE_WITH_MD3_LOADER_
+#undef _IRR_COMPILE_WITH_MD3_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_3DS_LOADER_ if you want to load 3D Studio Max files
 #define _IRR_COMPILE_WITH_3DS_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_3DS_LOADER_
+#undef _IRR_COMPILE_WITH_3DS_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_COLLADA_LOADER_ if you want to load Collada files
 #define _IRR_COMPILE_WITH_COLLADA_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_COLLADA_LOADER_
+#undef _IRR_COMPILE_WITH_COLLADA_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_CSM_LOADER_ if you want to load Cartography Shop files
 #define _IRR_COMPILE_WITH_CSM_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_CSM_LOADER_
+#undef _IRR_COMPILE_WITH_CSM_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_BSP_LOADER_ if you want to load Quake 3 BSP files
 #define _IRR_COMPILE_WITH_BSP_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_BSP_LOADER_
+#undef _IRR_COMPILE_WITH_BSP_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_DMF_LOADER_ if you want to load DeleD files
 #define _IRR_COMPILE_WITH_DMF_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_DMF_LOADER_
+#undef _IRR_COMPILE_WITH_DMF_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_LMTS_LOADER_ if you want to load LMTools files
 #define _IRR_COMPILE_WITH_LMTS_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_LMTS_LOADER_
+#undef _IRR_COMPILE_WITH_LMTS_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_MY3D_LOADER_ if you want to load MY3D files
 #define _IRR_COMPILE_WITH_MY3D_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_MY3D_LOADER_
+#undef _IRR_COMPILE_WITH_MY3D_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_OBJ_LOADER_ if you want to load Wavefront OBJ files
 #define _IRR_COMPILE_WITH_OBJ_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_OBJ_LOADER_
+#undef _IRR_COMPILE_WITH_OBJ_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_OCT_LOADER_ if you want to load FSRad OCT files
 #define _IRR_COMPILE_WITH_OCT_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_OCT_LOADER_
+#undef _IRR_COMPILE_WITH_OCT_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_LWO_LOADER_ if you want to load Lightwave3D files
 #define _IRR_COMPILE_WITH_LWO_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_LWO_LOADER_
+#undef _IRR_COMPILE_WITH_LWO_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_STL_LOADER_ if you want to load stereolithography files
 #define _IRR_COMPILE_WITH_STL_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_STL_LOADER_
+#undef _IRR_COMPILE_WITH_STL_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_PLY_LOADER_ if you want to load Polygon (Stanford Triangle) files
 #define _IRR_COMPILE_WITH_PLY_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_PLY_LOADER_
+#undef _IRR_COMPILE_WITH_PLY_LOADER_
+#endif
+//! Define _IRR_COMPILE_WITH_SMF_LOADER_ if you want to load 3D World Studio mesh files
+#define _IRR_COMPILE_WITH_SMF_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_SMF_LOADER_
+#undef _IRR_COMPILE_WITH_SMF_LOADER_
+#endif
 
 //! Define _IRR_COMPILE_WITH_IRR_WRITER_ if you want to write static .irrMesh files
 #define _IRR_COMPILE_WITH_IRR_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_IRR_WRITER_
+#undef _IRR_COMPILE_WITH_IRR_WRITER_
+#endif
 //! Define _IRR_COMPILE_WITH_COLLADA_WRITER_ if you want to write Collada files
 #define _IRR_COMPILE_WITH_COLLADA_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_COLLADA_WRITER_
+#undef _IRR_COMPILE_WITH_COLLADA_WRITER_
+#endif
 //! Define _IRR_COMPILE_WITH_STL_WRITER_ if you want to write .stl files
 #define _IRR_COMPILE_WITH_STL_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_STL_WRITER_
+#undef _IRR_COMPILE_WITH_STL_WRITER_
+#endif
 //! Define _IRR_COMPILE_WITH_OBJ_WRITER_ if you want to write .obj files
 #define _IRR_COMPILE_WITH_OBJ_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_OBJ_WRITER_
+#undef _IRR_COMPILE_WITH_OBJ_WRITER_
+#endif
 //! Define _IRR_COMPILE_WITH_PLY_WRITER_ if you want to write .ply files
 #define _IRR_COMPILE_WITH_PLY_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_PLY_WRITER_
+#undef _IRR_COMPILE_WITH_PLY_WRITER_
+#endif
 
 //! Define _IRR_COMPILE_WITH_BMP_LOADER_ if you want to load .bmp files
 //! Disabling this loader will also disable the built-in font
 #define _IRR_COMPILE_WITH_BMP_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_BMP_LOADER_
+#undef _IRR_COMPILE_WITH_BMP_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_JPG_LOADER_ if you want to load .jpg files
 #define _IRR_COMPILE_WITH_JPG_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_JPG_LOADER_
+#undef _IRR_COMPILE_WITH_JPG_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_PCX_LOADER_ if you want to load .pcx files
 #define _IRR_COMPILE_WITH_PCX_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_PCX_LOADER_
+#undef _IRR_COMPILE_WITH_PCX_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_PNG_LOADER_ if you want to load .png files
 #define _IRR_COMPILE_WITH_PNG_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_PNG_LOADER_
+#undef _IRR_COMPILE_WITH_PNG_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_PPM_LOADER_ if you want to load .ppm/.pgm/.pbm files
 #define _IRR_COMPILE_WITH_PPM_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_PPM_LOADER_
+#undef _IRR_COMPILE_WITH_PPM_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_PSD_LOADER_ if you want to load .psd files
 #define _IRR_COMPILE_WITH_PSD_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_PSD_LOADER_
+#undef _IRR_COMPILE_WITH_PSD_LOADER_
+#endif
+//! Define _IRR_COMPILE_WITH_DDS_LOADER_ if you want to load .dds files
+// Outcommented because
+// a) it doesn't compile on 64-bit currently
+// b) anyone enabling it should be aware that S3TC compression algorithm which might be used in that loader
+// is patented in the US by S3 and they do collect license fees when it's used in applications.
+// So if you are unfortunate enough to develop applications for US market and their broken patent system be careful.
+// #define _IRR_COMPILE_WITH_DDS_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_DDS_LOADER_
+#undef _IRR_COMPILE_WITH_DDS_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_TGA_LOADER_ if you want to load .tga files
 #define _IRR_COMPILE_WITH_TGA_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_TGA_LOADER_
+#undef _IRR_COMPILE_WITH_TGA_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_WAL_LOADER_ if you want to load .wal files
 #define _IRR_COMPILE_WITH_WAL_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_WAL_LOADER_
+#undef _IRR_COMPILE_WITH_WAL_LOADER_
+#endif
+//! Define _IRR_COMPILE_WITH_LMP_LOADER_ if you want to load .lmp files
+#define _IRR_COMPILE_WITH_LMP_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_LMP_LOADER_
+#undef _IRR_COMPILE_WITH_LMP_LOADER_
+#endif
 //! Define _IRR_COMPILE_WITH_RGB_LOADER_ if you want to load Silicon Graphics .rgb/.rgba/.sgi/.int/.inta/.bw files
 #define _IRR_COMPILE_WITH_RGB_LOADER_
+#ifdef NO_IRR_COMPILE_WITH_RGB_LOADER_
+#undef _IRR_COMPILE_WITH_RGB_LOADER_
+#endif
 
 //! Define _IRR_COMPILE_WITH_BMP_WRITER_ if you want to write .bmp files
 #define _IRR_COMPILE_WITH_BMP_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_BMP_WRITER_
+#undef _IRR_COMPILE_WITH_BMP_WRITER_
+#endif
 //! Define _IRR_COMPILE_WITH_JPG_WRITER_ if you want to write .jpg files
 #define _IRR_COMPILE_WITH_JPG_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_JPG_WRITER_
+#undef _IRR_COMPILE_WITH_JPG_WRITER_
+#endif
 //! Define _IRR_COMPILE_WITH_PCX_WRITER_ if you want to write .pcx files
 #define _IRR_COMPILE_WITH_PCX_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_PCX_WRITER_
+#undef _IRR_COMPILE_WITH_PCX_WRITER_
+#endif
 //! Define _IRR_COMPILE_WITH_PNG_WRITER_ if you want to write .png files
 #define _IRR_COMPILE_WITH_PNG_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_PNG_WRITER_
+#undef _IRR_COMPILE_WITH_PNG_WRITER_
+#endif
 //! Define _IRR_COMPILE_WITH_PPM_WRITER_ if you want to write .ppm files
 #define _IRR_COMPILE_WITH_PPM_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_PPM_WRITER_
+#undef _IRR_COMPILE_WITH_PPM_WRITER_
+#endif
 //! Define _IRR_COMPILE_WITH_PSD_WRITER_ if you want to write .psd files
 #define _IRR_COMPILE_WITH_PSD_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_PSD_WRITER_
+#undef _IRR_COMPILE_WITH_PSD_WRITER_
+#endif
 //! Define _IRR_COMPILE_WITH_TGA_WRITER_ if you want to write .tga files
 #define _IRR_COMPILE_WITH_TGA_WRITER_
+#ifdef NO_IRR_COMPILE_WITH_TGA_WRITER_
+#undef _IRR_COMPILE_WITH_TGA_WRITER_
+#endif
 
 //! Define __IRR_COMPILE_WITH_ZIP_ARCHIVE_LOADER_ if you want to open ZIP and GZIP archives
 /** ZIP reading has several more options below to configure. */
 #define __IRR_COMPILE_WITH_ZIP_ARCHIVE_LOADER_
+#ifdef NO__IRR_COMPILE_WITH_ZIP_ARCHIVE_LOADER_
+#undef __IRR_COMPILE_WITH_ZIP_ARCHIVE_LOADER_
+#endif
 #ifdef __IRR_COMPILE_WITH_ZIP_ARCHIVE_LOADER_
 //! Define _IRR_COMPILE_WITH_ZLIB_ to enable compiling the engine using zlib.
 /** This enables the engine to read from compressed .zip archives. If you
 disable this feature, the engine can still read archives, but only uncompressed
 ones. */
 #define _IRR_COMPILE_WITH_ZLIB_
+#ifdef NO_IRR_COMPILE_WITH_ZLIB_
+#undef _IRR_COMPILE_WITH_ZLIB_
+#endif
 //! Define _IRR_USE_NON_SYSTEM_ZLIB_ to let irrlicht use the zlib which comes with irrlicht.
 /** If this is commented out, Irrlicht will try to compile using the zlib
 installed on the system. This is only used when _IRR_COMPILE_WITH_ZLIB_ is
 defined. */
-//#define _IRR_USE_NON_SYSTEM_ZLIB_
+#define _IRR_USE_NON_SYSTEM_ZLIB_
+#ifdef NO_IRR_USE_NON_SYSTEM_ZLIB_
+#undef _IRR_USE_NON_SYSTEM_ZLIB_
+#endif
 //! Define _IRR_COMPILE_WITH_ZIP_ENCRYPTION_ if you want to read AES-encrypted ZIP archives
 #define _IRR_COMPILE_WITH_ZIP_ENCRYPTION_
+#ifdef NO_IRR_COMPILE_WITH_ZIP_ENCRYPTION_
+#undef _IRR_COMPILE_WITH_ZIP_ENCRYPTION_
+#endif
 //! Define _IRR_COMPILE_WITH_BZIP2_ if you want to support bzip2 compressed zip archives
 /** bzip2 is superior to the original zip file compression modes, but requires
 a certain amount of memory for decompression and adds several files to the
 library. */
 #define _IRR_COMPILE_WITH_BZIP2_
+#ifdef NO_IRR_COMPILE_WITH_BZIP2_
+#undef _IRR_COMPILE_WITH_BZIP2_
+#endif
 //! Define _IRR_USE_NON_SYSTEM_BZLIB_ to let irrlicht use the bzlib which comes with irrlicht.
 /** If this is commented out, Irrlicht will try to compile using the bzlib
 installed on the system. This is only used when _IRR_COMPILE_WITH_BZLIB_ is
 defined. */
-//#define _IRR_USE_NON_SYSTEM_BZLIB_
+#define _IRR_USE_NON_SYSTEM_BZLIB_
+#ifdef NO_IRR_USE_NON_SYSTEM_BZLIB_
+#undef _IRR_USE_NON_SYSTEM_BZLIB_
+#endif
 //! Define _IRR_COMPILE_WITH_LZMA_ if you want to use LZMA compressed zip files.
 /** LZMA is a very efficient compression code, known from 7zip. Irrlicht
 currently only supports zip archives, though. */
 #define _IRR_COMPILE_WITH_LZMA_
+#ifdef NO_IRR_COMPILE_WITH_LZMA_
+#undef _IRR_COMPILE_WITH_LZMA_
+#endif
 #endif
 
 //! Define __IRR_COMPILE_WITH_MOUNT_ARCHIVE_LOADER_ if you want to mount folders as archives
 #define __IRR_COMPILE_WITH_MOUNT_ARCHIVE_LOADER_
+#ifdef NO__IRR_COMPILE_WITH_MOUNT_ARCHIVE_LOADER_
+#undef __IRR_COMPILE_WITH_MOUNT_ARCHIVE_LOADER_
+#endif
 //! Define __IRR_COMPILE_WITH_PAK_ARCHIVE_LOADER_ if you want to open ID software PAK archives
 #define __IRR_COMPILE_WITH_PAK_ARCHIVE_LOADER_
+#ifdef NO__IRR_COMPILE_WITH_PAK_ARCHIVE_LOADER_
+#undef __IRR_COMPILE_WITH_PAK_ARCHIVE_LOADER_
+#endif
 //! Define __IRR_COMPILE_WITH_NPK_ARCHIVE_LOADER_ if you want to open Nebula Device NPK archives
 #define __IRR_COMPILE_WITH_NPK_ARCHIVE_LOADER_
+#ifdef NO__IRR_COMPILE_WITH_NPK_ARCHIVE_LOADER_
+#undef __IRR_COMPILE_WITH_NPK_ARCHIVE_LOADER_
+#endif
 //! Define __IRR_COMPILE_WITH_TAR_ARCHIVE_LOADER_ if you want to open TAR archives
 #define __IRR_COMPILE_WITH_TAR_ARCHIVE_LOADER_
+#ifdef NO__IRR_COMPILE_WITH_TAR_ARCHIVE_LOADER_
+#undef __IRR_COMPILE_WITH_TAR_ARCHIVE_LOADER_
+#endif
+//! Define __IRR_COMPILE_WITH_WAD_ARCHIVE_LOADER_ if you want to open WAD archives
+#define __IRR_COMPILE_WITH_WAD_ARCHIVE_LOADER_
+#ifdef NO__IRR_COMPILE_WITH_WAD_ARCHIVE_LOADER_
+#undef __IRR_COMPILE_WITH_WAD_ARCHIVE_LOADER_
+#endif
 
 //! Set FPU settings
 /** Irrlicht should use approximate float and integer fpu techniques
@@ -383,6 +668,9 @@ precision will be lower but speed higher. currently X86 only
 */
 #if !defined(_IRR_OSX_PLATFORM_) && !defined(_IRR_SOLARIS_PLATFORM_)
 	//#define IRRLICHT_FAST_MATH
+	#ifdef NO_IRRLICHT_FAST_MATH
+	#undef IRRLICHT_FAST_MATH
+	#endif
 #endif
 
 // Some cleanup and standard stuff
@@ -502,5 +790,43 @@ precision will be lower but speed higher. currently X86 only
 	#undef _IRR_COMPILE_WITH_JOYSTICK_EVENTS_
 #endif
 
+//! Define __IRR_HAS_S64 if the irr::s64 type should be enable (needs long long, available on most platforms, but not part of ISO C++ 98)
+#define __IRR_HAS_S64
+#ifdef NO__IRR_HAS_S64
+#undef __IRR_HAS_S64
+#endif
+
+#if defined(__BORLANDC__)
+	#include <tchar.h>
+
+	// Borland 5.5.1 does not have _strcmpi defined
+	#if __BORLANDC__ == 0x551
+	//    #define _strcmpi strcmpi
+		#undef _tfinddata_t
+		#undef _tfindfirst
+		#undef _tfindnext
+
+		#define _tfinddata_t __tfinddata_t
+		#define _tfindfirst  __tfindfirst
+		#define _tfindnext   __tfindnext
+		typedef long intptr_t;
+	#endif
+
+#endif
+
+#ifdef _DEBUG
+	//! A few attributes are written in CSceneManager when _IRR_SCENEMANAGER_DEBUG is enabled
+	// NOTE: Those attributes were used always until 1.8.0 and became a global define for 1.8.1
+	// which is only enabled in debug because it had a large (sometimes >5%) impact on speed.
+	// A better solution in the long run is to break the interface and remove _all_ attribute
+	// access in functions like CSceneManager::drawAll and instead put that information in some
+	// own struct/class or in CSceneManager.
+	// See http://irrlicht.sourceforge.net/forum/viewtopic.php?f=2&t=48211 for the discussion.
+	#define _IRR_SCENEMANAGER_DEBUG
+	#ifdef NO_IRR_SCENEMANAGER_DEBUG
+		#undef _IRR_SCENEMANAGER_DEBUG
+	#endif
+#endif
+
 #endif // __IRR_COMPILE_CONFIG_H_INCLUDED__
 
